@@ -17,6 +17,9 @@ describe 'basic vitrage' do
           warning('Vitrage is not yet packaged on Ubuntu systems.')
         }
         'RedHat': {
+          package { 'python-setproctitle':
+            ensure => present,
+          }
           include ::openstack_integration::vitrage
         }
         default: {
